@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/components/preferences/languages.js"
+//@line 40 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/preferences/languages.js"
 
 var gLanguagesDialog = {
 
@@ -141,9 +141,11 @@ var gLanguagesDialog = {
       this._acceptLanguages[languages[i]] = true;
     }
 
-    if (this._activeLanguages.childNodes.length > 0) 
+    if (this._activeLanguages.childNodes.length > 0) {
+      this._activeLanguages.ensureIndexIsVisible(selectedIndex);
       this._activeLanguages.selectedIndex = selectedIndex;
-    
+    }
+
     return undefined;
   },
   
