@@ -1,4 +1,4 @@
-//@line 41 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 42 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 
 const PREF_APP_UPDATE_ENABLED             = "app.update.enabled";
 const PREF_APP_UPDATE_AUTO                = "app.update.auto";
@@ -16,7 +16,8 @@ const PREF_APP_UPDATE_LASTUPDATETIME_FMT  = "app.update.lastUpdateTime.%ID%";
 const PREF_APP_EXTENSIONS_VERSION         = "app.extensions.version";
 const PREF_GENERAL_USERAGENT_LOCALE       = "general.useragent.locale";
 const PREF_APP_UPDATE_INCOMPATIBLE_MODE   = "app.update.incompatible.mode";
-const PREF_UPDATE_NEVER_BRANCH            = "app.update.never.";
+const PREF_UPDATE_NEVER_BRANCH            = "app.update.never."
+const PREF_PARTNER_BRANCH                 = "app.partner.";
 
 const URI_UPDATE_PROMPT_DIALOG  = "chrome://mozapps/content/update/updates.xul";
 const URI_UPDATE_HISTORY_DIALOG = "chrome://mozapps/content/update/history.xul";
@@ -44,7 +45,7 @@ const MODE_TRUNCATE = 0x20;
 const PERMS_FILE      = 0644;
 const PERMS_DIRECTORY = 0755;
 
-const STATE_NONE            = null;
+const STATE_NONE            = "null";
 const STATE_DOWNLOADING     = "downloading";
 const STATE_PENDING         = "pending";
 const STATE_APPLYING        = "applying";
@@ -79,8 +80,8 @@ const Node = Components.interfaces.nsIDOMNode;
 
 var gApp        = null;
 var gPref       = null;
-var gOS         = null;
 var gABI        = null;
+var gOSVersion  = null;
 var gConsole    = null;
 var gLogEnabled = { };
 
@@ -91,7 +92,7 @@ var gLogEnabled = { };
  */  
 function LOG(module, string) {
   if (module in gLogEnabled) {
-    dump("*** " + module + ":" + string + "\n");
+    dump("*** " + module + ": " + string + "\n");
     gConsole.logStringMessage(string);
   }
 }
@@ -413,6 +414,44 @@ function getLocale() {
   return gPref.getCharPref(PREF_GENERAL_USERAGENT_LOCALE);
 }
 
+/**
+ * Read the update channel from defaults only.  We do this to ensure that
+ * the channel is tightly coupled with the application and does not apply
+ * to other instances of the application that may use the same profile.
+ */
+function getUpdateChannel() {
+  var channel = "default";
+  var prefName;
+  var prefValue;
+
+  var defaults =
+      gPref.QueryInterface(Components.interfaces.nsIPrefService).
+      getDefaultBranch(null);
+  try {
+    channel = defaults.getCharPref(PREF_APP_UPDATE_CHANNEL);
+  } catch (e) {
+    // use default when pref not found
+  }
+
+  try {
+    var partners = gPref.getChildList(PREF_PARTNER_BRANCH, { });
+    if (partners.length) {
+      channel += "-cck";
+      partners.sort();
+
+      for each (prefName in partners) {
+        prefValue = gPref.getCharPref(prefName);
+        channel += "-" + prefValue;
+      }
+    }
+  }
+  catch (e) {
+    Components.utils.reportError(e);
+  }
+
+  return channel;
+}
+
 /**
  * An enumeration of items in a JS array.
  * @constructor
@@ -493,10 +532,17 @@ function readStringFromFile(file) {
   return text;
 }
 
+function getObserverService()
+{
+  return Components.classes["@mozilla.org/observer-service;1"]
+                   .getService(Components.interfaces.nsIObserverService);
+}
+
 /**
  * Update Patch
  * @param   patch
  *          A <patch> element to initialize this object with
+ * @throws if patch has a size of 0
  * @constructor
  */
 function UpdatePatch(patch) {
@@ -508,6 +554,11 @@ function UpdatePatch(patch) {
     case "selected":
       this.selected = attr.value == "true";
       break;
+    case "size":
+      if (0 == parseInt(attr.value)) {
+        LOG("UpdatePatch", "0-sized patch!");
+        throw Components.results.NS_ERROR_ILLEGAL_VALUE;
+      }
     default:
       this[attr.name] = attr.value;
       break;
@@ -618,6 +669,7 @@ UpdatePatch.prototype = {
  * Implements nsIUpdate
  * @param   update
  *          An <update> element to initialize this object with
+ * @throws if the update contains no patches
  * @constructor
  */
 function Update(update) {
@@ -625,6 +677,7 @@ function Update(update) {
   this._patches = [];
   this.installDate = 0;
   this.isCompleteUpdate = false;
+  this.channel = "default";
 
   // Null <update>, assume this is a message container and do no 
   // further initialization
@@ -638,8 +691,16 @@ function Update(update) {
       continue;
 
     patchElement.QueryInterface(Components.interfaces.nsIDOMElement);
-    this._patches.push(new UpdatePatch(patchElement));
+    try {
+      var patch = new UpdatePatch(patchElement);
+    } catch (e) {
+      continue;
+    }
+    this._patches.push(patch);
   }
+  
+  if (0 == this._patches.length)
+    throw Components.results.NS_ERROR_ILLEGAL_VALUE;
 
   for (var i = 0; i < update.attributes.length; ++i) {
     var attr = update.attributes.item(i);
@@ -652,6 +713,8 @@ function Update(update) {
       this.isSecurityUpdate = attr.value == "true";
     else if (attr.name == "detailsURL")
       this._detailsURL = attr.value;
+    else if (attr.name == "channel")
+      this.channel = attr.value;
     else
       this[attr.name] = attr.value;
   }
@@ -732,8 +795,9 @@ Update.prototype = {
       try {
         // Try using a default details URL supplied by the distribution
         // if the update XML does not supply one.
-        return gPref.getComplexValue(PREF_APP_UPDATE_URL_DETAILS,
-                                     nsIPrefLocalizedString).data;
+        var formatter = Components.classes["@mozilla.org/toolkit/URLFormatterService;1"]
+                                  .getService(Components.interfaces.nsIURLFormatter);
+        return formatter.formatURLPref(PREF_APP_UPDATE_URL_DETAILS);
       }
       catch (e) {
       }
@@ -757,6 +821,7 @@ Update.prototype = {
     update.setAttribute("statusText", this.statusText);
     update.setAttribute("buildID", this.buildID);
     update.setAttribute("isCompleteUpdate", this.isCompleteUpdate);
+    update.setAttribute("channel", this.channel);
     updates.documentElement.appendChild(update);
     
     for (var p in this._properties) {
@@ -816,7 +881,8 @@ Update.prototype = {
    * See nsISupports.idl
    */
   QueryInterface: function(iid) {
-    if (!iid.equals(Components.interfaces.nsIUpdate) &&
+    if (!iid.equals(Components.interfaces.nsIUpdate_MOZILLA_1_8_BRANCH) &&
+        !iid.equals(Components.interfaces.nsIUpdate) &&
         !iid.equals(Components.interfaces.nsIPropertyBag) &&
         !iid.equals(Components.interfaces.nsIWritablePropertyBag) &&
         !iid.equals(Components.interfaces.nsISupports))
@@ -836,8 +902,6 @@ function UpdateService() {
                     .QueryInterface(Components.interfaces.nsIXULRuntime);
   gPref = Components.classes["@mozilla.org/preferences-service;1"]
                     .getService(Components.interfaces.nsIPrefBranch2);
-  gOS   = Components.classes["@mozilla.org/observer-service;1"]
-                    .getService(Components.interfaces.nsIObserverService);
   gConsole = Components.classes["@mozilla.org/consoleservice;1"]
                        .getService(Components.interfaces.nsIConsoleService);  
 
@@ -849,15 +913,29 @@ function UpdateService() {
     LOG("UpdateService", "XPCOM ABI unknown: updates are not possible.");
   }
 
-//@line 900 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+  try {
+    var sysInfo = 
+      Components.classes["@mozilla.org/system-info;1"]
+                .getService(Components.interfaces.nsIPropertyBag2);
+
+    gOSVersion = encodeURIComponent(sysInfo.getProperty("name") + " " +  
+                                    sysInfo.getProperty("version"));
+  }
+  catch (e) {
+    LOG("UpdateService", "OS Version unknown: updates are not possible.");
+  }
+
+//@line 977 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 
   // Start the update timer only after a profile has been selected so that the
   // appropriate values for the update check are read from the user's profile.  
-  gOS.addObserver(this, "profile-after-change", false);
+  var os = getObserverService();
+
+  os.addObserver(this, "profile-after-change", false);
 
   // Observe xpcom-shutdown to unhook pref branch observers above to avoid 
   // shutdown leaks.
-  gOS.addObserver(this, "xpcom-shutdown", false);
+  os.addObserver(this, "xpcom-shutdown", false);
 }
 
 UpdateService.prototype = {
@@ -877,18 +955,19 @@ UpdateService.prototype = {
    *          Additional data
    */
   observe: function(subject, topic, data) {
+    var os = getObserverService();
+
     switch (topic) {
     case "profile-after-change":
-      gOS.removeObserver(this, "profile-after-change");
+      os.removeObserver(this, "profile-after-change");
       this._start();
       break;
     case "xpcom-shutdown":
-      gOS.removeObserver(this, "xpcom-shutdown");
+      os.removeObserver(this, "xpcom-shutdown");
       
       // Release Services
       gApp      = null;
       gPref     = null;
-      gOS       = null;
       gConsole  = null;
       break;
     }
@@ -960,10 +1039,7 @@ UpdateService.prototype = {
       var shouldCleanup = true;
       var update = um.activeUpdate;
       if (!update) {
-        if ((status == STATE_SUCCEEDED) && (um.updateCount >= 1))
-          update = um.getUpdateAt(0);
-        else
-          update = new Update(null);
+        update = new Update(null);
       }
       update.state = status;
       var sbs = 
@@ -1166,7 +1242,7 @@ UpdateService.prototype = {
     catch (e) {
       licenseAccepted = false;
     }
-    
+
     var updateEnabled = getPref("getBoolPref", PREF_APP_UPDATE_ENABLED, true);
     if (!updateEnabled) {
       LOG("Checker", "_shouldPrompt: Not prompting because update is " + 
@@ -1197,36 +1273,7 @@ UpdateService.prototype = {
         "ignore incompatibilities");
     return false;
   },
- 
-  /**
-   * Determine if we have all the strings we need to show the major update UI
-   */
-  haveStringsForMajorUpdate: function() {
-    var sbs = 
-        Components.classes["@mozilla.org/intl/stringbundle;1"].
-        getService(Components.interfaces.nsIStringBundleService);
-    var updateBundle = sbs.createBundle(URI_UPDATES_PROPERTIES);
-    
-    var stringNamesForMajorUpdate =
-        ["introType_minor_app", "introType_major_app_and_version",
-         "licenseContentNotFound", "updateMoreInfoContentNotFound",
-         "licenseContentDownloading", "updateMoreInfoContentDownloading",
-         "updatesfound_minor.title", "updatesfound_major.title",
-         "downloadButton_minor", "downloadButton_major", "neverButton"];
-
-    try {
-      for (var i = 0; i < stringNamesForMajorUpdate.length; ++i) {
-        if (!updateBundle.GetStringFromName(stringNamesForMajorUpdate[i]))
-          return false;
-      }
-      return true;
-    }
-    catch (ex) {
-      LOG("Checker", "haveStringsForMajorUpdate: missing a string: " + ex);
-      return false;
-    }
-  },
- 
+  
   /**
    * Determine which of the specified updates should be installed.
    * @param   updates
@@ -1251,12 +1298,6 @@ UpdateService.prototype = {
         minorUpdate = newestMinor = updates[i];
     }
 
-    // XXX sspitzer hack for the MOZILLA_1_8_0_BRANCH
-    if (majorUpdate && !this.haveStringsForMajorUpdate()) {
-      LOG("Checker", "selectUpdate:  have a major update, but can't offer it because we are missing strings");
-      majorUpdate = null;
-    }
-
     // IMPORTANT
     // If there's a minor update, always try and fetch that one first, 
     // otherwise use the newest major update.
@@ -1287,7 +1328,7 @@ UpdateService.prototype = {
     var update = this.selectUpdate(updates, updates.length);
     if (!update)
       return;
-    
+
     // check if the user said "never" to this version
     // this check is done here, and not in selectUpdate() so that
     // the user can get an upgrade they said "never" to if they
@@ -1362,6 +1403,10 @@ UpdateService.prototype = {
     if (!gABI)
       return false;
 
+    // If we don't know the OS version we're updating, we can't update.
+    if (!gOSVersion)
+      return false;
+
     return true;
   },
   
@@ -1485,6 +1530,12 @@ UpdateManager.prototype = {
           continue;
 
         updateElement.QueryInterface(Components.interfaces.nsIDOMElement);
+        try {
+          var update = new Update(updateElement);
+        } catch (e) {
+          LOG("UpdateManager", "_loadXMLFileIntoArray: invalid update");
+          continue;
+        }
         result.push(new Update(updateElement));
       }
     }
@@ -1531,14 +1582,16 @@ UpdateManager.prototype = {
    * See nsIUpdateService.idl
    */
   get activeUpdate() {
-    if (this._activeUpdate &&
-        this._activeUpdate.serviceURL != Checker.prototype.updateURL) {
-      // User switched channels, clear out any old active updates and remove
-      // partial downloads
-      this._activeUpdate = null;
+    if (this._activeUpdate) {
+      this._activeUpdate.QueryInterface(Components.interfaces.nsIUpdate_MOZILLA_1_8_BRANCH);
+      if (this._activeUpdate.channel != getUpdateChannel()) {
+        // User switched channels, clear out any old active updates and remove
+        // partial downloads
+        this._activeUpdate = null;
       
-      // Destroy the updates directory, since we're done with it.
-      cleanUpUpdatesDir();
+        // Destroy the updates directory, since we're done with it.
+        cleanUpUpdatesDir();
+      }
     }
     return this._activeUpdate;
   },
@@ -1565,9 +1618,11 @@ UpdateManager.prototype = {
   _addUpdate: function(update) {
     if (!update)
       return;
+    this._ensureUpdates();
     if (this._updates) {
       for (var i = 0; i < this._updates.length; ++i) {
-        if (this._updates[i].version == update.version &&
+        if (this._updates[i] &&
+            this._updates[i].version == update.version &&
             this._updates[i].buildID == update.buildID) {
           // Replace the existing entry with the new value, updating
           // all metadata.
@@ -1717,7 +1772,7 @@ Checker.prototype = {
    * The nsIUpdateCheckListener callback
    */
   _callback : null,
-  
+ 
   /**
    * The URL of the update service XML file to connect to that contains details
    * about available updates.
@@ -1743,21 +1798,11 @@ Checker.prototype = {
       return null;
     }
 
-    // Read the update channel from defaults only.  We do this to ensure that
-    // the channel is tightly coupled with the application and does not apply
-    // to other instances of the application that may use the same profile.
-    function getUpdateChannel() {
-      try {
-        return defaults.getCharPref(PREF_APP_UPDATE_CHANNEL);
-      } catch (e) {
-        return "default";  // failover when pref not found
-      }
-    }
-
     url = url.replace(/%PRODUCT%/g, gApp.name);
     url = url.replace(/%VERSION%/g, gApp.version);
     url = url.replace(/%BUILD_ID%/g, gApp.appBuildID);
     url = url.replace(/%BUILD_TARGET%/g, gApp.OS + "_" + gABI);
+    url = url.replace(/%OS_VERSION%/g, gOSVersion);
     url = url.replace(/%LOCALE%/g, getLocale());
     url = url.replace(/%CHANNEL%/g, getUpdateChannel());
     url = url.replace(/\+/g, "%2B");
@@ -1772,7 +1817,7 @@ Checker.prototype = {
   checkForUpdates: function(listener, force) {
     if (!listener)
       throw Components.results.NS_ERROR_NULL_POINTER;
-      
+    
     if (!this.updateURL || (!this.enabled && !force))
       return;
       
@@ -1828,8 +1873,14 @@ Checker.prototype = {
         continue;
 
       updateElement.QueryInterface(Components.interfaces.nsIDOMElement);
-      var update = new Update(updateElement);
+      try {
+        var update = new Update(updateElement);
+      } catch (e) {
+        LOG("Checker", "Invalid <update/>, ignoring...");
+        continue;
+      }
       update.serviceURL = this.updateURL;
+      update.channel = getUpdateChannel();
       updates.push(update);
     }
 
@@ -1863,6 +1914,8 @@ Checker.prototype = {
       update.statusText = getStatusTextFromCode(404, 404);
       this._callback.onError(event.target, update);
     }
+
+    this._request = null;
   },
   
   /**
@@ -1888,6 +1941,8 @@ Checker.prototype = {
     var update = new Update(null);
     update.statusText = getStatusTextFromCode(status, 200);
     this._callback.onError(request, update);
+
+    this._request = null;
   },
   
   /**
@@ -2106,8 +2161,13 @@ Downloader.prototype = {
 
     // Restore the updateDir since we may have deleted it.
     updateDir = getUpdatesDir();
-    
-    selectedPatch.selected = true;
+
+    // if update only contains a partial patch, selectedPatch == null here if
+    // the partial patch has been attempted and fails and we're trying to get a
+    // complete patch
+    if (selectedPatch)    
+      selectedPatch.selected = true;
+
     update.isCompleteUpdate = useComplete;
     
     // Reset the Active Update object on the Update Manager and flush the
@@ -2290,6 +2350,10 @@ Downloader.prototype = {
     const NS_BINDING_ABORTED = 0x804b0002;
     const NS_ERROR_ABORT = 0x80004004;
     if (Components.isSuccessCode(status)) {
+      var sbs = 
+          Components.classes["@mozilla.org/intl/stringbundle;1"].
+          getService(Components.interfaces.nsIStringBundleService);
+      var updateStrings = sbs.createBundle(URI_UPDATES_PROPERTIES);
       if (this._verifyDownload()) {
         state = STATE_PENDING;
         
@@ -2302,15 +2366,12 @@ Downloader.prototype = {
         // Tell the updater.exe we're ready to apply.
         writeStatusFile(getUpdatesDir(), state);
         this._update.installDate = (new Date()).getTime();
-        this._update.statusText = "Install Pending";
+        this._update.statusText = updateStrings.
+          GetStringFromName("installPending");
       } else {
         LOG("Downloader", "onStopRequest: download verification failed");
         state = STATE_DOWNLOAD_FAILED;
         
-        var sbs = 
-            Components.classes["@mozilla.org/intl/stringbundle;1"].
-            getService(Components.interfaces.nsIStringBundleService);
-        var updateStrings = sbs.createBundle(URI_UPDATES_PROPERTIES);
         var brandStrings = sbs.createBundle(URI_BRAND_PROPERTIES);
         var brandShortName = brandStrings.GetStringFromName("brandShortName");
         this._update.statusText = updateStrings.
@@ -2367,17 +2428,25 @@ Downloader.prototype = {
     
     if (state == STATE_DOWNLOAD_FAILED) {
       if (!this._update.isCompleteUpdate) {
+        var allFailed = true;
+  
         // If we were downloading a patch and the patch verification phase 
         // failed, log this and then commence downloading the complete update.
         LOG("Downloader", "onStopRequest: Verification of patch failed, downloading complete update");
         this._update.isCompleteUpdate = true;
         var status = this.downloadUpdate(this._update);
-        if (status == STATE_NONE)
+
+        if (status == STATE_NONE) {
           cleanupActiveUpdate();
+        } else {
+          allFailed = false;
+        }
         // This will reset the |.state| property on this._update if a new 
         // download initiates.
       }
-      else {
+    
+      // if we still fail after trying a complete download, give up completely
+      if (allFailed) {
         // In all other failure cases, i.e. we're S.O.L. - no more failing over
         // ...
         
@@ -2385,12 +2454,13 @@ Downloader.prototype = {
         // (e.g. because the user closed the download window) and there was an
         // error, we must notify now. Otherwise we can keep the failure to 
         // ourselves since the user won't be expecting it. 
-        var fgdl = false;
         try {
-          fgdl = this._update.getProperty("foregroundDownload");
+          this._update.QueryInterface(Components.interfaces.nsIWritablePropertyBag);
+          var fgdl = this._update.getProperty("foregroundDownload");
         }
         catch (e) {
         }
+      
         if (fgdl == "true") {
           var prompter = 
               Components.classes["@mozilla.org/updates/update-prompt;1"].
@@ -2400,6 +2470,9 @@ Downloader.prototype = {
           prompter.showUpdateError(this._update);
         }
       }
+
+      // the complete download succeeded or total failure was handled, so exit
+      return;
     }
 
     // Do this after *everything* else, since it will likely cause the app 
@@ -2450,9 +2523,7 @@ Downloader.prototype = {
  * @constructor
  */
 function TimerManager() {
-  gOS = Components.classes["@mozilla.org/observer-service;1"]
-                  .getService(Components.interfaces.nsIObserverService);
-  gOS.addObserver(this, "xpcom-shutdown", false);
+  getObserverService().addObserver(this, "xpcom-shutdown", false);
 
   const nsITimer = Components.interfaces.nsITimer;
   this._timer = Components.classes["@mozilla.org/timer;1"]
@@ -2467,9 +2538,11 @@ TimerManager.prototype = {
    */
   observe: function(subject, topic, data) {
     if (topic == "xpcom-shutdown") {
-      gOS.removeObserver(this, "xpcom-shutdown");
+     getObserverService().removeObserver(this, "xpcom-shutdown");
 
       // Release everything we hold onto. 
+      for (var timerID in this._timers)
+        delete this._timers[timerID];
       this._timer = null;
       this._timers = null;
     }
@@ -2545,7 +2618,7 @@ TimerManager.prototype = {
   }
 };
 
-//@line 2596 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2670 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 /**
  * UpdatePrompt
  * An object which can prompt the user with information about updates, request
@@ -2687,7 +2760,7 @@ UpdatePrompt.prototype = {
     return this;
   }
 };
-//@line 2738 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2812 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 
 var gModule = {
   registerSelf: function(componentManager, fileSpec, location, type) {
@@ -2719,42 +2792,33 @@ var gModule = {
     throw Components.results.NS_ERROR_NO_INTERFACE;
   },
   
-  _makeFactory: #1= function(ctor) {
-    function ci(outer, iid) {
-      if (outer != null)
-        throw Components.results.NS_ERROR_NO_AGGREGATION;
-      return (new ctor()).QueryInterface(iid);
-    } 
-    return { createInstance: ci };
-  },
-  
   _objects: {
     service: { CID        : Components.ID("{B3C290A6-3943-4B89-8BBE-C01EB7B3B311}"),
                contractID : "@mozilla.org/updates/update-service;1",
                className  : "Update Service",
-               factory    : #1#(UpdateService)
+               factory    : makeFactory(UpdateService)
              },
     checker: { CID        : Components.ID("{898CDC9B-E43F-422F-9CC4-2F6291B415A3}"),
                contractID : "@mozilla.org/updates/update-checker;1",
                className  : "Update Checker",
-               factory    : #1#(Checker)
+               factory    : makeFactory(Checker)
              },
-//@line 2790 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2855 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     prompt:  { CID        : Components.ID("{27ABA825-35B5-4018-9FDD-F99250A0E722}"),
                contractID : "@mozilla.org/updates/update-prompt;1",
                className  : "Update Prompt",
-               factory    : #1#(UpdatePrompt)
+               factory    : makeFactory(UpdatePrompt)
              },
-//@line 2796 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2861 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     timers:  { CID        : Components.ID("{B322A5C0-A419-484E-96BA-D7182163899F}"),
                contractID : "@mozilla.org/updates/timer-manager;1",
                className  : "Timer Manager",
-               factory    : #1#(TimerManager)
+               factory    : makeFactory(TimerManager)
              },
     manager: { CID        : Components.ID("{093C2356-4843-4C65-8709-D7DBCBBE7DFB}"),
                contractID : "@mozilla.org/updates/update-manager;1",
                className  : "Update Manager",
-               factory    : #1#(UpdateManager)
+               factory    : makeFactory(UpdateManager)
              },
   },
   
@@ -2763,6 +2827,19 @@ var gModule = {
   }
 };
 
+/**
+ * Creates a factory for instances of an object created using the passed-in
+ * constructor.
+ */
+function makeFactory(ctor) {
+  function ci(outer, iid) {
+    if (outer != null)
+      throw Components.results.NS_ERROR_NO_AGGREGATION;
+    return (new ctor()).QueryInterface(iid);
+  } 
+  return { createInstance: ci };
+}
+  
 function NSGetModule(compMgr, fileSpec) {
   return gModule;
 }
@@ -2776,14 +2853,14 @@ function NSGetModule(compMgr, fileSpec) {
  *          the specified update, false otherwise.
  */
 function isCompatible(update) {
-//@line 2827 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2905 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
   var em = 
       Components.classes["@mozilla.org/extensions/manager;1"].
       getService(Components.interfaces.nsIExtensionManager);
   var items = em.getIncompatibleItemList("", update.extensionVersion,
     nsIUpdateItem.TYPE_ADDON, false, { });
   return items.length == 0;
-//@line 2836 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2914 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 }
 
 /**
@@ -2802,7 +2879,7 @@ function showPromptIfNoIncompatibilities(update) {
     prompter.showUpdateAvailable(update);
   }
 
-//@line 2855 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2933 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
   /**
    * Determines if an addon is compatible with a particular update.
    * @param   addon
@@ -2902,6 +2979,6 @@ function showPromptIfNoIncompatibilities(update) {
     em.update([], 0, mode != 0, listener);
   }
   else
-//@line 2955 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 3033 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     showPrompt(update);
 }
