@@ -1,4 +1,4 @@
-//@line 40 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 40 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
 
 
 /**
@@ -11,8 +11,11 @@
  *          If null, there will be no referrer header and no security check.
  * @param postData Form POST data, or null.
  * @param event The triggering event (for the purpose of determining whether to open in the background), or null
+ * @param allowThirdPartyFixup if true, then we allow the URL text to be sent to third party
+ * services (e.g., Google's I Feel Lucky) for interpretation. This parameter may be undefined in
+ * which case it is treated as false.
  */ 
-function openNewTabWith(href, sourceURL, postData, event)
+function openNewTabWith(href, sourceURL, postData, event, allowThirdPartyFixup)
 {
   if (sourceURL)
     urlSecurityCheck(href, sourceURL);
@@ -44,10 +47,11 @@ function openNewTabWith(href, sourceURL, postData, event)
 
   var referrerURI = sourceURL ? makeURI(sourceURL) : null;
 
-  browser.loadOneTab(href, referrerURI, originCharset, postData, loadInBackground);
+  browser.loadOneTab(href, referrerURI, originCharset, postData, loadInBackground,
+                     allowThirdPartyFixup || false);
 }
 
-function openNewWindowWith(href, sourceURL, postData)
+function openNewWindowWith(href, sourceURL, postData, allowThirdPartyFixup)
 {
   if (sourceURL)
     urlSecurityCheck(href, sourceURL);
@@ -62,7 +66,8 @@ function openNewWindowWith(href, sourceURL, postData)
 
   var referrerURI = sourceURL ? makeURI(sourceURL) : null;
 
-  window.openDialog(getBrowserURL(), "_blank", "chrome,all,dialog=no", href, charsetArg, referrerURI, postData);
+  window.openDialog(getBrowserURL(), "_blank", "chrome,all,dialog=no",
+                    href, charsetArg, referrerURI, postData, allowThirdPartyFixup);
 }
 
 /**
@@ -248,8 +253,8 @@ function internalSave(aURL, aDocument, aDefaultFileName, aContentDisposition,
       charset = aDocument.characterSet;
     else if (aReferrer)
       charset = aReferrer.originCharset;
-    initFileInfo(fileInfo, aURL, aDocument, aContentType, aContentDisposition,
-                 charset);
+    initFileInfo(fileInfo, aURL, charset, aDocument,
+                 aContentType, aContentDisposition);
     var fpParams = {
       fpTitleKey: aFilePickerTitleKey,
       isDocument: isDocument,
@@ -389,18 +394,16 @@ function FileInfo(aSuggestedFileName, aFileName, aFileBaseName, aFileExt, aUri)
  * for confirmation in the file picker dialog.
  * @param aFI A FileInfo structure into which we'll put the results of this method.
  * @param aURL The String representation of the URL of the document being saved
+ * @param aURLCharset The charset of aURL.
  * @param aDocument The document to be saved
  * @param aContentType The content type we're saving, if it could be
  *        determined by the caller.
  * @param aContentDisposition The content-disposition header for the object
  *        we're saving, if it could be determined by the caller.
- * @param aURLCharset The charset of aURL.
  */
-function initFileInfo(aFI, aURL, aDocument, aContentType, aContentDisposition,
-                      aURLCharset)
+function initFileInfo(aFI, aURL, aURLCharset, aDocument,
+                      aContentType, aContentDisposition)
 {
-  if (!aURLCharset && aDocument && aDocument.characterSet)
-    aURLCharset = aDocument.characterSet;
   try {
     // Get an nsIURI object from aURL if possible:
     try {
@@ -459,9 +462,9 @@ function getTargetFile(aFpP, aSkipPrompt)
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
     
-//@line 506 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 509 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
     return "Home";
-//@line 509 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 512 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
   }
   
   function getDownloadsFolder(aFolder)
@@ -849,7 +852,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 900 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 903 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/content/contentAreaUtils.js"
       
   // Fix up the file name we're saving to to include the default extension
   var i = aFile.lastIndexOf(".");
