@@ -1,4 +1,4 @@
-//@line 41 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+//@line 42 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
 
 ///////////////////////////////////////////////////////////////////////////////
 // Globals
@@ -20,7 +20,11 @@ var gActiveDownloads  = [];
 // opened by the xpinstall manager prevents the window from being closed after
 // each download completes (because xpinstall downloads are done sequentially, 
 // not concurrently) 
-var gCanAutoClose     = true;
+var gCanAutoClose   = true;
+
+// If the user has interacted with the window in a significant way, we should
+// not auto-close the window. Tough UI decisions about what is "significant."
+var gUserInteracted = false;
 
 ///////////////////////////////////////////////////////////////////////////////
 // Utility Functions 
@@ -143,14 +147,12 @@ function autoClose(aDownload)
     // For the moment, just use the simple heuristic that if this window was
     // opened by the download process, rather than by the user, it should auto-close
     // if the pref is set that way. If the user opened it themselves, it should
-    // not close until they explicitly close it. 
-    // We may like to revisit this in a bit more detail later, perhaps we want
-    // to keep it up if the user messes with it in a significant way.
+    // not close until they explicitly close it.
     var pref = Components.classes["@mozilla.org/preferences-service;1"]
                         .getService(Components.interfaces.nsIPrefBranch);
     var autoClose = pref.getBoolPref(PREF_BDM_CLOSEWHENDONE)
     if (autoClose && (!window.opener || window.opener.location.href == window.location.href) &&
-        gCanAutoClose)
+        gCanAutoClose && !gUserInteracted)
       gCloseDownloadManager();
   }
 }
@@ -383,6 +385,7 @@ function onDownloadOpenWith(aEvent)
 
 function onDownloadProperties(aEvent)
 {
+  gUserInteracted = true;
   window.openDialog("chrome://mozapps/content/downloads/downloadProperties.xul",
                     "_blank", "modal,centerscreen,chrome,resizable=no", aEvent.target.id);
 }
@@ -715,20 +718,6 @@ var gDownloadViewController = {
   }
 };
 
-function onDownloadShowOptions()
-{
-  var windowManager = Components.classes['@mozilla.org/appshell/window-mediator;1'].getService();
-  var windowManagerInterface = windowManager.QueryInterface(Components.interfaces.nsIWindowMediator);
-  var topWindow = windowManagerInterface.getMostRecentWindow("Browser:Options");
-  if (topWindow) {
-    topWindow.focus();
-    topWindow.switchPage("catDownloadsButton");
-  }
-  else
-    openDialog("chrome://browser/content/pref/pref.xul", "PrefWindow",
-              "chrome,titlebar,resizable,modal", "catDownloadsButton");
-}
-
 function onDownloadShowInfo()
 {
   if (gDownloadsView.selectedItem)
@@ -749,8 +738,15 @@ function initAutoDownloadDisplay()
 
     function getSpecialFolderKey(aFolderType) 
     {
-//@line 803 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
-      return "Home";
+    if (aFolderType == "Desktop")
+      return "Desk";
+
+    if (aFolderType != "Downloads")
+      throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
+
+//@line 793 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+    return "Home";
+//@line 796 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
     }
     
     function getDownloadsFolder(aFolder)
